@@ -1,5 +1,5 @@
 use byteorder::{ByteOrder, LittleEndian, WriteBytesExt};
-use solana_rbpf::{aligned_memory::AlignedMemory, ebpf::HOST_ALIGN};
+use gemachain_rbpf::{aligned_memory::AlignedMemory, ebpf::HOST_ALIGN};
 use gemachain_sdk::{
     account::{ReadableAccount, WritableAccount},
     bpf_loader_deprecated,
